==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/CadToolBar/ts/CadToolBar_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>CadToolBar</name>
    <message>
        <location filename="../CadToolBar.js" line="+49"/>
        <source>Widgets</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Seleccionador de método de entrada que utiliza o menu de contexto dos elementos de texto
O seu tema não suporta menus de navegação ou de widgets.</translatorcomment>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>CAD Toolbar</source>
        <translation>Barra de ferramentas CAD</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Toggle Title Bar</source>
        <translation>Mostrar barra de título</translation>
    </message>
    <message>
        <source>CAD Tool Bar</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Barra de ferramentas CAD</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translatorcomment>--exact match--
--file: LibraryBrowser_pt.ts--
Tamanho ícone:
Fazer ferramentas principais menores</translatorcomment>
        <translation>Tamanho ícone:</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Pixel</source>
        <translatorcomment>--exact match--
--file: pt.po--
PPM
XPM</translatorcomment>
        <translation>Pixel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translatorcomment>--exact match--
--file: pt.po--
Espaçamento Mínimo da Grade (px)
Espaçamento Mínimo da Grade (px):</translatorcomment>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Columns:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Entre as colunas:
Colunas:</translatorcomment>
        <translation>Colunas:</translation>
    </message>
</context>
<context>
    <name>CadToolBarPanel</name>
    <message>
        <location filename="../CadToolBarPanel.js" line="+76"/>
        <source>Back</source>
        <translation>Retorne</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/CadToolBar/ts/CadToolBar_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>CadToolBar</name>
    <message>
        <location filename="../CadToolBar.js" line="+51"/>
        <source>Widgets</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Seleccionador de método de entrada que utiliza o menu de contexto dos elementos de texto
O seu tema não suporta menus de navegação ou de widgets.</translatorcomment>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>CAD Toolbar</source>
        <translation>Barra de Ferramentas CAD</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Vertical/Horizontal</source>
        <translation>Vertical/Horizontal</translation>
    </message>
    <message>
        <source>Toggle Title Bar</source>
        <translation type="vanished">Alterne a Barra de Título</translation>
    </message>
    <message>
        <source>CAD Tool Bar</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Barra de ferramentas CAD</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translatorcomment>--exact match--
--file: LibraryBrowser_pt.ts--
Tamanho ícone:
Fazer ferramentas principais menores</translatorcomment>
        <translation>Tamanho do Ícone:</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Pixel</source>
        <translatorcomment>--exact match--
--file: pt.po--
PPM
XPM</translatorcomment>
        <translation>Pixel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translatorcomment>--exact match--
--file: pt.po--
Espaçamento Mínimo da Grade (px)
Espaçamento Mínimo da Grade (px):</translatorcomment>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Columns:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Entre as colunas:
Colunas:</translatorcomment>
        <translation>Colunas:</translation>
    </message>
</context>
<context>
    <name>CadToolBarPanel</name>
    <message>
        <location filename="../CadToolBarPanel.js" line="+107"/>
        <source>Back</source>
        <translation>Retorne</translation>
    </message>
</context>
</TS>
